@echo off
rem ===========================================================================
rem
rem Script Name:  getcid.cmd
rem               Get CID Tool for V220
rem
rem ===========================================================================
rem
rem All Rights Reserved, Copyright (c) Digital Process Ltd. 2023
rem
rem ===========================================================================
rem getcid.exe -Product Version 2.2.0.0-
rem 
rem Revision History:
rem
rem RELEASE     AUTHOR  DATE         COMMENT
rem ==========  ======  ===========  =======
rem 8.1.0.2     DIPRO   2016/05/26   Create
rem 8.1.0.2     DIPRO   2016/06/01   Change 1bit code
rem 8.2.2.4     DIPRO   2017/03/17   Modify
rem 8.2.5.2     DIPRO   2017/12/07   Modify
rem 9.0.1.4     DIPRO   2018/06/20   Modify
rem 9.1.0.6     DIPRO   2019/01/11   Modify
rem 10.0.0.5    DIPRO   2019/05/28   Modify
rem 11.0.0.7    DIPRO   2019/12/10   Modify
rem 1.6.0.0     DIPRO   2022/07/11   Modify
rem 2.2.0.0     DIPRO   2023/02/22   Modify
rem ===========================================================================

rem: Environment---------------------------------------------------------------
set CDIR=%~dp0
set TMP_DIR=C:\Temp\V220CID
set GCID=getcid
set CID_DIR=getcid\%GCID%
set NAME_DIR=""

rem: Get CID Information-------------------------------------------------------
cls
echo.
echo              Get CID Information for Siemens Product Use
echo __________________________________________________________________________
echo.
echo   It is batch file to acquire CID information for the
echo       Siemens product license application.
echo.
echo   Note: I make %TMP_DIR% folder automatically when I execute this program
echo       when there is not %TMP_DIR% folder.
echo __________________________________________________________________________
echo.
echo   Press any key to continue . . .
echo   When you cancel it, press [Ctrl] + [c] key.
echo.
pause >NUL

rem: Input Company Name--------------------------------------------------------
cls
echo.
echo   Please input company name.
echo.
set /p NAME_DIR=Company Name :
if "%NAME_DIR%"x==""""x set NAME_DIR=CID

rem: Create Execute Folder and Copy File---------------------------------------
if not exist "%TMP_DIR%" mkdir %TMP_DIR%
cd /d %TMP_DIR%
if exist %CDIR%%CID_DIR%.ex_ copy /y %CDIR%%CID_DIR%.ex_ .\
if exist %CDIR%%CID_DIR%.exe copy /y %CDIR%%CID_DIR%.exe .\

if exist %TMP_DIR%\%GCID%.ex_ (rename %TMP_DIR%\%GCID%.ex_ %GCID%.exe 2>NUL)
if not exist %TMP_DIR%\%GCID%.exe goto :Error2 >nul

rem: Clear File----------------------------------------------------------------
if exist %TMP_DIR%\"%NAME_DIR%".txt del /q %TMP_DIR%\"%NAME_DIR%".txt

rem: Execute Getcid Program for Current CID------------------------------------
rem:echo.
rem:echo @**********************************************************
rem:echo   Start getcid program. Press [Enter] key.
rem:echo @**********************************************************
rem:echo.
echo =========== >> %TMP_DIR%\"%NAME_DIR%".txt
echo * CID Information >> %TMP_DIR%\"%NAME_DIR%".txt
echo =========== >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
%TMP_DIR%\%GCID%.exe -nopause >> %TMP_DIR%\"%NAME_DIR%".txt

rem: Execute Getcid Program for All CID----------------------------------------
rem:echo.
rem:echo @**********************************************************
rem:echo @Getting CID Information. Press [Enter] key.
rem:echo @**********************************************************
rem:echo.
echo =========== >> %TMP_DIR%\"%NAME_DIR%".txt
echo * All CID Information >> %TMP_DIR%\"%NAME_DIR%".txt
echo =========== >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
%TMP_DIR%\%GCID%.exe -allcomposite -nopause >> %TMP_DIR%\"%NAME_DIR%".txt

rem: Get Computer Name---------------------------------------------------------
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
echo ================== >> %TMP_DIR%\"%NAME_DIR%".txt
echo * Computer Name >> %TMP_DIR%\"%NAME_DIR%".txt
echo ================== >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
hostname >> %TMP_DIR%\"%NAME_DIR%".txt

rem: Get MAC Address-----------------------------------------------------------
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
echo =================== >> %TMP_DIR%\"%NAME_DIR%".txt
echo * MAC Address Information >> %TMP_DIR%\"%NAME_DIR%".txt
echo =================== >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
ipconfig /all >> %TMP_DIR%\"%NAME_DIR%".txt

rem: Get OS Information--------------------------------------------------------
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo. >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
echo ============== >> %TMP_DIR%\"%NAME_DIR%".txt
echo * OS Information >> %TMP_DIR%\"%NAME_DIR%".txt
echo ============== >> %TMP_DIR%\"%NAME_DIR%".txt
echo.
systeminfo >> %TMP_DIR%\"%NAME_DIR%".txt

rem: End Message---------------------------------------------------------------
cls
if exist %TMP_DIR%\"%NAME_DIR%".txt explorer %TMP_DIR%
if not exist %TMP_DIR%\"%NAME_DIR%".txt goto Error1
echo.
echo   **********************************************************
echo   Complete getcid program.
echo   Please send %TMP_DIR%\"%NAME_DIR%".txt file.
echo.
echo   Press any key to end.
echo   **********************************************************
echo.
pause >NUL
goto EOF

:Error1
echo.
echo   **********************************************************
echo   Failed to get cid information.
echo   Please refer to the support center.
echo.
echo   Press any key to end.
echo   **********************************************************
echo.
pause >NUL
goto :EOF

:Error2
cls
echo.
echo   **********************************************************
echo   Failed to get cid information.
echo   Don't exist %TMP_DIR%\getcid.exe file.
echo.
echo   Press any key to end.
echo   **********************************************************
echo.
pause >NUL
goto :EOF

:EOF
